var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input, Output, EventEmitter, ComponentFactoryResolver } from '@angular/core';
import { Router } from '@angular/router';
let NodeComponent = class NodeComponent {
    constructor(resolver, router) {
        this.resolver = resolver;
        this.router = router;
        this.clickEvent = new EventEmitter();
        this.extendEvent = new EventEmitter();
        this.nodeChangeEvent = new EventEmitter();
    }
    set nodeData(v) {
        this._nodeData = v;
        this.init();
    }
    get nodeData() {
        return this._nodeData;
    }
    init() {
        if (this.needShow(this.nodeData)) {
            this.nodeData.show = true;
        }
    }
    needShow(node) {
        if (node.show) {
            return true;
        }
        if (node.subNode == null || node.subNode.length == 0) {
            return false;
        }
        let result = false;
        for (let n of node.subNode) {
            if (this.needShow(n)) {
                result = true;
            }
        }
        return result;
    }
    ngOnInit() {
        this.initClsObj();
    }
    initClsObj() {
        if (this.options && this.options.iconCls) {
            this.iconClsFolder = this.options.iconCls.folder;
            this.iconClsFile = this.options.iconCls.file;
            this.iconClsExpand = this.options.iconCls.expand;
        }
    }
    getFileIcon() {
        if (this.iconClsFile && (!this.nodeData[this.keyChild] || this.nodeData[this.keyChild].length == 0)) {
            return this.iconClsFile;
        }
        return '';
    }
    getFolderIcon() {
        if (this.iconClsFolder && this.nodeData[this.keyChild] && this.nodeData[this.keyChild].length > 0) {
            return this.iconClsFolder;
        }
        return '';
    }
    getExpandIcon() {
        if (this.iconClsExpand && this.nodeData.show) {
            return this.iconClsExpand;
        }
        return '';
    }
    clickNode(nodeData) {
        this.clickEvent.emit(this.nodeData);
    }
    changeShow() {
        this.nodeData.show = !this.nodeData.show;
        this.extendEvent.emit(this.nodeData);
    }
    doNodeFn(option) {
        if (option.fn) {
            option.fn(this.nodeData);
        }
    }
    _clickNode(event) {
        this.clickEvent.emit(event);
    }
    _extendNode(event) {
        this.extendEvent.emit(event);
    }
    ngOnChanges(changes) {
    }
    getText() {
        if (this._nodeData.show) {
            return '-';
        }
        else {
            return '+';
        }
    }
};
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], NodeComponent.prototype, "root", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], NodeComponent.prototype, "keyId", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], NodeComponent.prototype, "keyName", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], NodeComponent.prototype, "keyChild", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], NodeComponent.prototype, "options", void 0);
__decorate([
    Output(),
    __metadata("design:type", Object)
], NodeComponent.prototype, "clickEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", Object)
], NodeComponent.prototype, "extendEvent", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object),
    __metadata("design:paramtypes", [Object])
], NodeComponent.prototype, "nodeData", null);
__decorate([
    Output(),
    __metadata("design:type", Object)
], NodeComponent.prototype, "nodeChangeEvent", void 0);
NodeComponent = __decorate([
    Component({
        selector: 'dc-node',
        template: `
  <div class="display-flex width-100 flex-direction-column node-container">
  <div class="display-flex width-100">
    <div class="before-node">
    </div>
    <div class="icon" [class.cursor-pointer]="nodeData[keyChild]!=null && nodeData[keyChild].length>0">
      <i (click)="changeShow()" *ngIf="nodeData[keyChild]!=null && nodeData[keyChild].length>0">{{getText()}}</i>
    </div>
    <div class="tree-icon" *ngIf="options && options['iconCls']" [ngClass]="[getFileIcon(),getFolderIcon(),getExpandIcon()]">
    </div>
    <div class="cursor-pointer" (click)="clickNode(nodeData)"
         [class.active]="nodeData.lighthight" [class.selected]="nodeData.selected">
      {{nodeData[keyName]}}
    </div>
    <div class="" *ngIf="options && options.actionBtn" style="float: right;">
      <ng-template ngFor let-actbtn [ngForOf]="options.actionBtn">
        <i *ngIf="(root && !actbtn.rootHide) || !root" class="{{actbtn.cls}}"
           (click)="doNodeFn(actbtn)">{{actbtn.text}}</i>
      </ng-template>
    </div>
  </div>

  <div *ngIf="nodeData[keyChild]!=null && nodeData[keyChild].length>0 && nodeData.show"
       class="display-flex width-100 flex-direction-column sub-node-container">
    <div *ngFor="let node of nodeData[keyChild]">
      <div>
        <dc-node [nodeData]="node" [keyChild]="keyChild" [keyId]="keyId"
                 [options]="options" [keyName]="keyName"
                 (clickEvent)="_clickNode($event)" (extendEvent)="_extendNode($event)"></dc-node>
      </div>
    </div>
  </div>
</div>
  `,
        styles: [
            '.sub-node-container{margin-left: 10px;}',
            '.before-node{}',
            '.left-line{position: absolute;width: 1px;height: 100000px;border-left: 1px solid red;}',
            '.node-container{overflow: hidden;position: relative;};',
            '.icon{width: 10px;}',
            '.noIcon{margin-left: 10px;}',
            '.tree-icon{display: inline-block;width: 20px;height: 20px;}'
        ]
    }),
    __metadata("design:paramtypes", [ComponentFactoryResolver, Router])
], NodeComponent);
export { NodeComponent };
//# sourceMappingURL=node.component.js.map